/*
lkmonitor (Linux Kernel Monitor)

Application for monitoring and tuning a Linux kernel.

Copyright (C) 2005-2006  Fernando Apesteguía

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/
#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <string.h>
#include <stdio.h>

#include <bonobo.h>
#include <gnome.h>

#include "callbacks.h"
#include "interface.h"
#include "support.h"

#define GLADE_HOOKUP_OBJECT(component,widget,name) \
  g_object_set_data_full (G_OBJECT (component), name, \
    gtk_widget_ref (widget), (GDestroyNotify) gtk_widget_unref)

#define GLADE_HOOKUP_OBJECT_NO_REF(component,widget,name) \
  g_object_set_data (G_OBJECT (component), name, widget)

static GnomeUIInfo menu3_uiinfo[] =
{
  GNOMEUIINFO_MENU_EXIT_ITEM (on_quit1_activate, NULL),
  GNOMEUIINFO_END
};

static GnomeUIInfo menu4_uiinfo[] =
{
  GNOMEUIINFO_MENU_ABOUT_ITEM (on_about1_activate, NULL),
  GNOMEUIINFO_END
};

static GnomeUIInfo menubar1_uiinfo[] =
{
  GNOMEUIINFO_MENU_FILE_TREE (menu3_uiinfo),
  GNOMEUIINFO_MENU_HELP_TREE (menu4_uiinfo),
  GNOMEUIINFO_END
};

GtkWidget*
create_window1 (void)
{
  GtkWidget *window1;
  GdkPixbuf *window1_icon_pixbuf;
  GtkWidget *vbox1;
  GtkWidget *menubar1;
  GtkWidget *nb_main;
  GtkWidget *hbox2;
  GtkWidget *table1;
  GtkWidget *label226;
  GtkWidget *label227;
  GtkWidget *label228;
  GtkWidget *label229;
  GtkWidget *label230;
  GtkWidget *label231;
  GtkWidget *label232;
  GtkWidget *label233;
  GtkWidget *label234;
  GtkWidget *label235;
  GtkWidget *label236;
  GtkWidget *label237;
  GtkWidget *label238;
  GtkWidget *label239;
  GtkWidget *lbl_processor;
  GtkWidget *lbl_vendor;
  GtkWidget *lbl_family;
  GtkWidget *lbl_model;
  GtkWidget *lbl_model_name;
  GtkWidget *lbl_stepping;
  GtkWidget *lbl_Mhz;
  GtkWidget *lbl_cache;
  GtkWidget *lbl_fpu;
  GtkWidget *lbl_fpu_exception;
  GtkWidget *lbl_cpu_id_level;
  GtkWidget *lbl_wp;
  GtkWidget *lbl_bogomips;
  GtkWidget *scrolledwindow5;
  GtkWidget *viewport1;
  GtkWidget *lbl_flags;
  GtkWidget *hbox3;
  GtkWidget *image1;
  GtkWidget *label302;
  GtkWidget *hbox1;
  GtkWidget *table2;
  GtkWidget *lbl_total;
  GtkWidget *lbl_free;
  GtkWidget *lbl_buffers;
  GtkWidget *lbl_cached;
  GtkWidget *lbl_swap_cached;
  GtkWidget *lbl_active;
  GtkWidget *lbl_inactive;
  GtkWidget *lbl_dirty;
  GtkWidget *lbl_hp_total;
  GtkWidget *lbl_hp_free;
  GtkWidget *lbl_hp_size;
  GtkWidget *lbl_high_total;
  GtkWidget *lbl_high_free;
  GtkWidget *lbl_low_total;
  GtkWidget *lbl_low_free;
  GtkWidget *lbl_swap_total;
  GtkWidget *lbl_swap_free;
  GtkWidget *label245;
  GtkWidget *label246;
  GtkWidget *label248;
  GtkWidget *label247;
  GtkWidget *label249;
  GtkWidget *label250;
  GtkWidget *label251;
  GtkWidget *label252;
  GtkWidget *label253;
  GtkWidget *label254;
  GtkWidget *label255;
  GtkWidget *label256;
  GtkWidget *label257;
  GtkWidget *label244;
  GtkWidget *label258;
  GtkWidget *label259;
  GtkWidget *label260;
  GtkWidget *vbox3;
  GtkWidget *frame8;
  GtkWidget *alignment8;
  GtkWidget *table11;
  GtkWidget *pb_swap;
  GtkWidget *pb_mem;
  GtkWidget *label336;
  GtkWidget *hbox4;
  GtkWidget *image2;
  GtkWidget *label303;
  GtkWidget *table3;
  GtkWidget *hbox6;
  GtkWidget *image4;
  GtkWidget *label305;
  GtkWidget *hbox7;
  GtkWidget *image5;
  GtkWidget *label306;
  GtkWidget *scrolledwindow7;
  GtkWidget *gtv_block;
  GtkWidget *scrolledwindow6;
  GtkWidget *gtv_char;
  GtkWidget *btn_dev_load;
  GtkWidget *alignment11;
  GtkWidget *hbox12;
  GtkWidget *image10;
  GtkWidget *label340;
  GtkWidget *hbox5;
  GtkWidget *image3;
  GtkWidget *label304;
  GtkWidget *table4;
  GtkWidget *fr_identification;
  GtkWidget *alignment2;
  GtkWidget *table5;
  GtkWidget *ent_hostname;
  GtkWidget *label309;
  GtkWidget *label310;
  GtkWidget *ent_domainname;
  GtkWidget *label308;
  GtkWidget *frame3;
  GtkWidget *alignment3;
  GtkWidget *table6;
  GtkWidget *label312;
  GtkWidget *label313;
  GtkWidget *label314;
  GtkWidget *label316;
  GtkWidget *label315;
  GtkObject *spb_fdmax_adj;
  GtkWidget *spb_fdmax;
  GtkWidget *lbl_fda;
  GtkWidget *lbl_ufd;
  GtkWidget *lbl_ina;
  GtkWidget *lbl_inmax;
  GtkWidget *label311;
  GtkWidget *frame4;
  GtkWidget *alignment4;
  GtkWidget *table7;
  GtkWidget *label321;
  GtkWidget *label322;
  GtkWidget *label323;
  GtkObject *spb_max_pages_adj;
  GtkWidget *spb_max_pages;
  GtkObject *spb_max_segs_adj;
  GtkWidget *spb_max_segs;
  GtkObject *spb_seg_size_adj;
  GtkWidget *spb_seg_size;
  GtkWidget *label320;
  GtkWidget *frame5;
  GtkWidget *alignment5;
  GtkWidget *table8;
  GtkWidget *label325;
  GtkWidget *label326;
  GtkWidget *label335;
  GtkObject *spb_mq_adj;
  GtkWidget *spb_mq;
  GtkObject *spb_max_mpq_adj;
  GtkWidget *spb_max_mpq;
  GtkObject *spb_max_ms_adj;
  GtkWidget *spb_max_ms;
  GtkWidget *label324;
  GtkWidget *frame6;
  GtkWidget *alignment6;
  GtkWidget *table9;
  GtkObject *spb_sem_per_id_adj;
  GtkWidget *spb_sem_per_id;
  GtkObject *spb_sem_val_adj;
  GtkWidget *spb_sem_val;
  GtkObject *spb_ops_adj;
  GtkWidget *spb_ops;
  GtkObject *spb_sem_id_adj;
  GtkWidget *spb_sem_id;
  GtkWidget *label329;
  GtkWidget *label330;
  GtkWidget *label331;
  GtkWidget *label332;
  GtkWidget *label328;
  GtkWidget *frame7;
  GtkWidget *alignment7;
  GtkWidget *table10;
  GtkObject *spb_maxthreads_adj;
  GtkWidget *spb_maxthreads;
  GtkWidget *label334;
  GtkWidget *label333;
  GtkWidget *btn_write;
  GtkWidget *alignment10;
  GtkWidget *hbox11;
  GtkWidget *image9;
  GtkWidget *label339;
  GtkWidget *btn_load;
  GtkWidget *alignment9;
  GtkWidget *hbox10;
  GtkWidget *image8;
  GtkWidget *label338;
  GtkWidget *hbox8;
  GtkWidget *image6;
  GtkWidget *label307;
  GtkWidget *table12;
  GtkWidget *table15;
  GtkWidget *frame10;
  GtkWidget *alignment13;
  GtkWidget *table16;
  GtkWidget *table13;
  GtkWidget *label345;
  GtkWidget *label346;
  GtkWidget *label347;
  GtkWidget *label348;
  GtkWidget *label349;
  GtkWidget *label350;
  GtkWidget *label351;
  GtkWidget *label352;
  GtkWidget *lbl_context;
  GtkWidget *lbl_softirq;
  GtkWidget *lbl_irq;
  GtkWidget *lbl_iowait;
  GtkWidget *lbl_idle;
  GtkWidget *lbl_system;
  GtkWidget *lbl_nice;
  GtkWidget *lbl_user;
  GtkWidget *table17;
  GtkWidget *label363;
  GtkWidget *pb_cpu;
  GtkWidget *label344;
  GtkWidget *frame9;
  GtkWidget *alignment12;
  GtkWidget *table14;
  GtkWidget *label361;
  GtkWidget *label362;
  GtkWidget *pb_temp;
  GtkWidget *pb_batt;
  GtkWidget *label364;
  GtkWidget *label365;
  GtkWidget *frame11;
  GtkWidget *alignment14;
  GtkWidget *table18;
  GtkWidget *label367;
  GtkWidget *label368;
  GtkWidget *label369;
  GtkWidget *label370;
  GtkWidget *label371;
  GtkWidget *lbl_cap;
  GtkWidget *lbl_last_cap;
  GtkWidget *lbl_cap_warning;
  GtkWidget *lbl_cap_low;
  GtkWidget *lbl_batt_type;
  GtkWidget *hbox13;
  GtkWidget *image11;
  GtkWidget *label366;
  GtkWidget *label341;
  GtkWidget *hbox9;
  GtkWidget *image7;
  GtkWidget *label337;

  window1 = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_window_set_title (GTK_WINDOW (window1), _("lkmonitor"));
  gtk_window_set_position (GTK_WINDOW (window1), GTK_WIN_POS_CENTER);
  gtk_window_set_default_size (GTK_WINDOW (window1), 462, 342);
  gtk_window_set_resizable (GTK_WINDOW (window1), FALSE);
  window1_icon_pixbuf = create_pixbuf ("spider-shadow16.png");
  if (window1_icon_pixbuf)
    {
      gtk_window_set_icon (GTK_WINDOW (window1), window1_icon_pixbuf);
      gdk_pixbuf_unref (window1_icon_pixbuf);
    }

  vbox1 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox1);
  gtk_container_add (GTK_CONTAINER (window1), vbox1);

  menubar1 = gtk_menu_bar_new ();
  gtk_widget_show (menubar1);
  gtk_box_pack_start (GTK_BOX (vbox1), menubar1, FALSE, FALSE, 0);
  gnome_app_fill_menu (GTK_MENU_SHELL (menubar1), menubar1_uiinfo,
                       NULL, FALSE, 0);

  nb_main = gtk_notebook_new ();
  gtk_widget_show (nb_main);
  gtk_box_pack_start (GTK_BOX (vbox1), nb_main, TRUE, TRUE, 0);
  gtk_notebook_set_tab_pos (GTK_NOTEBOOK (nb_main), GTK_POS_LEFT);

  hbox2 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox2);
  gtk_container_add (GTK_CONTAINER (nb_main), hbox2);

  table1 = gtk_table_new (14, 2, FALSE);
  gtk_widget_show (table1);
  gtk_box_pack_start (GTK_BOX (hbox2), table1, TRUE, TRUE, 0);

  label226 = gtk_label_new (_("Processor"));
  gtk_widget_show (label226);
  gtk_table_attach (GTK_TABLE (table1), label226, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (label226), 0, 0);

  label227 = gtk_label_new (_("Vendor"));
  gtk_widget_show (label227);
  gtk_table_attach (GTK_TABLE (table1), label227, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (label227), 0, 0);

  label228 = gtk_label_new (_("Family"));
  gtk_widget_show (label228);
  gtk_table_attach (GTK_TABLE (table1), label228, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (label228), 0, 0);

  label229 = gtk_label_new (_("Model"));
  gtk_widget_show (label229);
  gtk_table_attach (GTK_TABLE (table1), label229, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (label229), 0, 0);

  label230 = gtk_label_new (_("Model name"));
  gtk_widget_show (label230);
  gtk_table_attach (GTK_TABLE (table1), label230, 0, 1, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (label230), 0, 0);

  label231 = gtk_label_new (_("Stepping"));
  gtk_widget_show (label231);
  gtk_table_attach (GTK_TABLE (table1), label231, 0, 1, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (label231), 0, 0);

  label232 = gtk_label_new (_("MHz"));
  gtk_widget_show (label232);
  gtk_table_attach (GTK_TABLE (table1), label232, 0, 1, 6, 7,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (label232), 0, 0);

  label233 = gtk_label_new (_("Cache"));
  gtk_widget_show (label233);
  gtk_table_attach (GTK_TABLE (table1), label233, 0, 1, 7, 8,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (label233), 0, 0);

  label234 = gtk_label_new (_("fpu"));
  gtk_widget_show (label234);
  gtk_table_attach (GTK_TABLE (table1), label234, 0, 1, 8, 9,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (label234), 0, 0);

  label235 = gtk_label_new (_("fpu exception"));
  gtk_widget_show (label235);
  gtk_table_attach (GTK_TABLE (table1), label235, 0, 1, 9, 10,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (label235), 0, 0);

  label236 = gtk_label_new (_("Cpu id. level"));
  gtk_widget_show (label236);
  gtk_table_attach (GTK_TABLE (table1), label236, 0, 1, 10, 11,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (label236), 0, 0);

  label237 = gtk_label_new (_("wp"));
  gtk_widget_show (label237);
  gtk_table_attach (GTK_TABLE (table1), label237, 0, 1, 11, 12,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (label237), 0, 0);

  label238 = gtk_label_new (_("BogoMIPS"));
  gtk_widget_show (label238);
  gtk_table_attach (GTK_TABLE (table1), label238, 0, 1, 12, 13,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (label238), 0, 0);

  label239 = gtk_label_new (_("Flags"));
  gtk_widget_show (label239);
  gtk_table_attach (GTK_TABLE (table1), label239, 0, 1, 13, 14,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (label239), 0, 0);

  lbl_processor = gtk_label_new ("");
  gtk_widget_show (lbl_processor);
  gtk_table_attach (GTK_TABLE (table1), lbl_processor, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (lbl_processor), 0, 0);

  lbl_vendor = gtk_label_new ("");
  gtk_widget_show (lbl_vendor);
  gtk_table_attach (GTK_TABLE (table1), lbl_vendor, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (lbl_vendor), 0, 0);

  lbl_family = gtk_label_new ("");
  gtk_widget_show (lbl_family);
  gtk_table_attach (GTK_TABLE (table1), lbl_family, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (lbl_family), 0, 0);

  lbl_model = gtk_label_new ("");
  gtk_widget_show (lbl_model);
  gtk_table_attach (GTK_TABLE (table1), lbl_model, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (lbl_model), 0, 0);

  lbl_model_name = gtk_label_new ("");
  gtk_widget_show (lbl_model_name);
  gtk_table_attach (GTK_TABLE (table1), lbl_model_name, 1, 2, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (lbl_model_name), 0, 0);

  lbl_stepping = gtk_label_new ("");
  gtk_widget_show (lbl_stepping);
  gtk_table_attach (GTK_TABLE (table1), lbl_stepping, 1, 2, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (lbl_stepping), 0, 0);

  lbl_Mhz = gtk_label_new ("");
  gtk_widget_show (lbl_Mhz);
  gtk_table_attach (GTK_TABLE (table1), lbl_Mhz, 1, 2, 6, 7,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (lbl_Mhz), 0, 0);

  lbl_cache = gtk_label_new ("");
  gtk_widget_show (lbl_cache);
  gtk_table_attach (GTK_TABLE (table1), lbl_cache, 1, 2, 7, 8,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (lbl_cache), 0, 0);

  lbl_fpu = gtk_label_new ("");
  gtk_widget_show (lbl_fpu);
  gtk_table_attach (GTK_TABLE (table1), lbl_fpu, 1, 2, 8, 9,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (lbl_fpu), 0, 0);

  lbl_fpu_exception = gtk_label_new ("");
  gtk_widget_show (lbl_fpu_exception);
  gtk_table_attach (GTK_TABLE (table1), lbl_fpu_exception, 1, 2, 9, 10,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (lbl_fpu_exception), 0, 0);

  lbl_cpu_id_level = gtk_label_new ("");
  gtk_widget_show (lbl_cpu_id_level);
  gtk_table_attach (GTK_TABLE (table1), lbl_cpu_id_level, 1, 2, 10, 11,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (lbl_cpu_id_level), 0, 0);

  lbl_wp = gtk_label_new ("");
  gtk_widget_show (lbl_wp);
  gtk_table_attach (GTK_TABLE (table1), lbl_wp, 1, 2, 11, 12,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (lbl_wp), 0, 0);

  lbl_bogomips = gtk_label_new ("");
  gtk_widget_show (lbl_bogomips);
  gtk_table_attach (GTK_TABLE (table1), lbl_bogomips, 1, 2, 12, 13,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (lbl_bogomips), 0, 0);

  scrolledwindow5 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_show (scrolledwindow5);
  gtk_table_attach (GTK_TABLE (table1), scrolledwindow5, 1, 2, 13, 14,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 5, 5);
  gtk_widget_set_size_request (scrolledwindow5, 250, -1);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow5), GTK_POLICY_ALWAYS, GTK_POLICY_NEVER);

  viewport1 = gtk_viewport_new (NULL, NULL);
  gtk_widget_show (viewport1);
  gtk_container_add (GTK_CONTAINER (scrolledwindow5), viewport1);

  lbl_flags = gtk_label_new ("");
  gtk_widget_show (lbl_flags);
  gtk_container_add (GTK_CONTAINER (viewport1), lbl_flags);
  gtk_misc_set_padding (GTK_MISC (lbl_flags), 5, 0);

  hbox3 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox3);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (nb_main), gtk_notebook_get_nth_page (GTK_NOTEBOOK (nb_main), 0), hbox3);

  image1 = create_pixmap (window1, "gnome-cpu.png");
  gtk_widget_show (image1);
  gtk_box_pack_start (GTK_BOX (hbox3), image1, FALSE, FALSE, 0);

  label302 = gtk_label_new (_("Processor"));
  gtk_widget_show (label302);
  gtk_box_pack_start (GTK_BOX (hbox3), label302, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (label302), 2, 0);

  hbox1 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox1);
  gtk_container_add (GTK_CONTAINER (nb_main), hbox1);

  table2 = gtk_table_new (17, 2, FALSE);
  gtk_widget_show (table2);
  gtk_box_pack_start (GTK_BOX (hbox1), table2, TRUE, TRUE, 0);

  lbl_total = gtk_label_new ("");
  gtk_widget_show (lbl_total);
  gtk_table_attach (GTK_TABLE (table2), lbl_total, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 3);
  gtk_misc_set_alignment (GTK_MISC (lbl_total), 0, 0);

  lbl_free = gtk_label_new ("");
  gtk_widget_show (lbl_free);
  gtk_table_attach (GTK_TABLE (table2), lbl_free, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 3);
  gtk_misc_set_alignment (GTK_MISC (lbl_free), 0, 0);

  lbl_buffers = gtk_label_new ("");
  gtk_widget_show (lbl_buffers);
  gtk_table_attach (GTK_TABLE (table2), lbl_buffers, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 3);
  gtk_misc_set_alignment (GTK_MISC (lbl_buffers), 0, 0);

  lbl_cached = gtk_label_new ("");
  gtk_widget_show (lbl_cached);
  gtk_table_attach (GTK_TABLE (table2), lbl_cached, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 3);
  gtk_misc_set_alignment (GTK_MISC (lbl_cached), 0, 0);

  lbl_swap_cached = gtk_label_new ("");
  gtk_widget_show (lbl_swap_cached);
  gtk_table_attach (GTK_TABLE (table2), lbl_swap_cached, 1, 2, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 3);
  gtk_misc_set_alignment (GTK_MISC (lbl_swap_cached), 0, 0);

  lbl_active = gtk_label_new ("");
  gtk_widget_show (lbl_active);
  gtk_table_attach (GTK_TABLE (table2), lbl_active, 1, 2, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 3);
  gtk_misc_set_alignment (GTK_MISC (lbl_active), 0, 0);

  lbl_inactive = gtk_label_new ("");
  gtk_widget_show (lbl_inactive);
  gtk_table_attach (GTK_TABLE (table2), lbl_inactive, 1, 2, 6, 7,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 3);
  gtk_misc_set_alignment (GTK_MISC (lbl_inactive), 0, 0);

  lbl_dirty = gtk_label_new ("");
  gtk_widget_show (lbl_dirty);
  gtk_table_attach (GTK_TABLE (table2), lbl_dirty, 1, 2, 7, 8,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 3);
  gtk_misc_set_alignment (GTK_MISC (lbl_dirty), 0, 0);

  lbl_hp_total = gtk_label_new ("");
  gtk_widget_show (lbl_hp_total);
  gtk_table_attach (GTK_TABLE (table2), lbl_hp_total, 1, 2, 8, 9,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 3);
  gtk_misc_set_alignment (GTK_MISC (lbl_hp_total), 0, 0);

  lbl_hp_free = gtk_label_new ("");
  gtk_widget_show (lbl_hp_free);
  gtk_table_attach (GTK_TABLE (table2), lbl_hp_free, 1, 2, 9, 10,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 3);
  gtk_misc_set_alignment (GTK_MISC (lbl_hp_free), 0, 0);

  lbl_hp_size = gtk_label_new ("");
  gtk_widget_show (lbl_hp_size);
  gtk_table_attach (GTK_TABLE (table2), lbl_hp_size, 1, 2, 10, 11,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 3);
  gtk_misc_set_alignment (GTK_MISC (lbl_hp_size), 0, 0);

  lbl_high_total = gtk_label_new ("");
  gtk_widget_show (lbl_high_total);
  gtk_table_attach (GTK_TABLE (table2), lbl_high_total, 1, 2, 11, 12,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 3);
  gtk_misc_set_alignment (GTK_MISC (lbl_high_total), 0, 0);

  lbl_high_free = gtk_label_new ("");
  gtk_widget_show (lbl_high_free);
  gtk_table_attach (GTK_TABLE (table2), lbl_high_free, 1, 2, 12, 13,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 3);
  gtk_misc_set_alignment (GTK_MISC (lbl_high_free), 0, 0);

  lbl_low_total = gtk_label_new ("");
  gtk_widget_show (lbl_low_total);
  gtk_table_attach (GTK_TABLE (table2), lbl_low_total, 1, 2, 13, 14,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 3);
  gtk_misc_set_alignment (GTK_MISC (lbl_low_total), 0, 0);

  lbl_low_free = gtk_label_new ("");
  gtk_widget_show (lbl_low_free);
  gtk_table_attach (GTK_TABLE (table2), lbl_low_free, 1, 2, 14, 15,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 3);
  gtk_misc_set_alignment (GTK_MISC (lbl_low_free), 0, 0);

  lbl_swap_total = gtk_label_new ("");
  gtk_widget_show (lbl_swap_total);
  gtk_table_attach (GTK_TABLE (table2), lbl_swap_total, 1, 2, 15, 16,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 3);
  gtk_misc_set_alignment (GTK_MISC (lbl_swap_total), 0, 0);

  lbl_swap_free = gtk_label_new ("");
  gtk_widget_show (lbl_swap_free);
  gtk_table_attach (GTK_TABLE (table2), lbl_swap_free, 1, 2, 16, 17,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 3);
  gtk_misc_set_alignment (GTK_MISC (lbl_swap_free), 0, 0);

  label245 = gtk_label_new (_("Total"));
  gtk_widget_show (label245);
  gtk_table_attach (GTK_TABLE (table2), label245, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 0);
  gtk_misc_set_alignment (GTK_MISC (label245), 0, 0);

  label246 = gtk_label_new (_("Free"));
  gtk_widget_show (label246);
  gtk_table_attach (GTK_TABLE (table2), label246, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 0);
  gtk_misc_set_alignment (GTK_MISC (label246), 0, 0);

  label248 = gtk_label_new (_("Cached"));
  gtk_widget_show (label248);
  gtk_table_attach (GTK_TABLE (table2), label248, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 0);
  gtk_misc_set_alignment (GTK_MISC (label248), 0, 0);

  label247 = gtk_label_new (_("Buffers"));
  gtk_widget_show (label247);
  gtk_table_attach (GTK_TABLE (table2), label247, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 0);
  gtk_misc_set_alignment (GTK_MISC (label247), 0, 0);

  label249 = gtk_label_new (_("Swap cached"));
  gtk_widget_show (label249);
  gtk_table_attach (GTK_TABLE (table2), label249, 0, 1, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 0);
  gtk_misc_set_alignment (GTK_MISC (label249), 0, 0);

  label250 = gtk_label_new (_("Active"));
  gtk_widget_show (label250);
  gtk_table_attach (GTK_TABLE (table2), label250, 0, 1, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 0);
  gtk_misc_set_alignment (GTK_MISC (label250), 0, 0);

  label251 = gtk_label_new (_("Inactive"));
  gtk_widget_show (label251);
  gtk_table_attach (GTK_TABLE (table2), label251, 0, 1, 6, 7,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 0);
  gtk_misc_set_alignment (GTK_MISC (label251), 0, 0);

  label252 = gtk_label_new (_("Dirty"));
  gtk_widget_show (label252);
  gtk_table_attach (GTK_TABLE (table2), label252, 0, 1, 7, 8,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 0);
  gtk_misc_set_alignment (GTK_MISC (label252), 0, 0);

  label253 = gtk_label_new (_("HugePages Total"));
  gtk_widget_show (label253);
  gtk_table_attach (GTK_TABLE (table2), label253, 0, 1, 8, 9,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 0);
  gtk_misc_set_alignment (GTK_MISC (label253), 0, 0);

  label254 = gtk_label_new (_("HugePages Free"));
  gtk_widget_show (label254);
  gtk_table_attach (GTK_TABLE (table2), label254, 0, 1, 9, 10,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 0);
  gtk_misc_set_alignment (GTK_MISC (label254), 0, 0);

  label255 = gtk_label_new (_("Hugepages size"));
  gtk_widget_show (label255);
  gtk_table_attach (GTK_TABLE (table2), label255, 0, 1, 10, 11,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 0);
  gtk_misc_set_alignment (GTK_MISC (label255), 0, 0);

  label256 = gtk_label_new (_("High total"));
  gtk_widget_show (label256);
  gtk_table_attach (GTK_TABLE (table2), label256, 0, 1, 11, 12,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 0);
  gtk_misc_set_alignment (GTK_MISC (label256), 0, 0);

  label257 = gtk_label_new (_("High free"));
  gtk_widget_show (label257);
  gtk_table_attach (GTK_TABLE (table2), label257, 0, 1, 12, 13,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 0);
  gtk_misc_set_alignment (GTK_MISC (label257), 0, 0);

  label244 = gtk_label_new (_("Low total"));
  gtk_widget_show (label244);
  gtk_table_attach (GTK_TABLE (table2), label244, 0, 1, 13, 14,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 0);
  gtk_misc_set_alignment (GTK_MISC (label244), 0, 0);

  label258 = gtk_label_new (_("Low free"));
  gtk_widget_show (label258);
  gtk_table_attach (GTK_TABLE (table2), label258, 0, 1, 14, 15,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 0);
  gtk_misc_set_alignment (GTK_MISC (label258), 0, 0);

  label259 = gtk_label_new (_("Swap total"));
  gtk_widget_show (label259);
  gtk_table_attach (GTK_TABLE (table2), label259, 0, 1, 15, 16,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 0);
  gtk_misc_set_alignment (GTK_MISC (label259), 0, 0);

  label260 = gtk_label_new (_("Swap free"));
  gtk_widget_show (label260);
  gtk_table_attach (GTK_TABLE (table2), label260, 0, 1, 16, 17,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 0);
  gtk_misc_set_alignment (GTK_MISC (label260), 0, 0);

  vbox3 = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vbox3);
  gtk_box_pack_start (GTK_BOX (hbox1), vbox3, TRUE, TRUE, 0);

  frame8 = gtk_frame_new (NULL);
  gtk_widget_show (frame8);
  gtk_box_pack_start (GTK_BOX (vbox3), frame8, TRUE, FALSE, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame8), GTK_SHADOW_NONE);

  alignment8 = gtk_alignment_new (0.5, 0.5, 1, 1);
  gtk_widget_show (alignment8);
  gtk_container_add (GTK_CONTAINER (frame8), alignment8);
  gtk_alignment_set_padding (GTK_ALIGNMENT (alignment8), 0, 0, 12, 0);

  table11 = gtk_table_new (2, 1, FALSE);
  gtk_widget_show (table11);
  gtk_container_add (GTK_CONTAINER (alignment8), table11);

  pb_swap = gtk_progress_bar_new ();
  gtk_widget_show (pb_swap);
  gtk_table_attach (GTK_TABLE (table11), pb_swap, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_progress_bar_set_pulse_step (GTK_PROGRESS_BAR (pb_swap), 0.01);
  gtk_progress_bar_set_text (GTK_PROGRESS_BAR (pb_swap), _("Swap"));

  pb_mem = gtk_progress_bar_new ();
  gtk_widget_show (pb_mem);
  gtk_table_attach (GTK_TABLE (table11), pb_mem, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_progress_bar_set_pulse_step (GTK_PROGRESS_BAR (pb_mem), 0.01);
  gtk_progress_bar_set_text (GTK_PROGRESS_BAR (pb_mem), _("Memory"));

  label336 = gtk_label_new (_("<b></b>"));
  gtk_widget_show (label336);
  gtk_frame_set_label_widget (GTK_FRAME (frame8), label336);
  gtk_label_set_use_markup (GTK_LABEL (label336), TRUE);

  hbox4 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox4);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (nb_main), gtk_notebook_get_nth_page (GTK_NOTEBOOK (nb_main), 1), hbox4);

  image2 = create_pixmap (window1, "gnome-dev-memory.png");
  gtk_widget_show (image2);
  gtk_box_pack_start (GTK_BOX (hbox4), image2, FALSE, FALSE, 0);

  label303 = gtk_label_new (_("Memory"));
  gtk_widget_show (label303);
  gtk_box_pack_start (GTK_BOX (hbox4), label303, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (label303), 2, 0);

  table3 = gtk_table_new (3, 2, FALSE);
  gtk_widget_show (table3);
  gtk_container_add (GTK_CONTAINER (nb_main), table3);

  hbox6 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox6);
  gtk_table_attach (GTK_TABLE (table3), hbox6, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);

  image4 = create_pixmap (window1, "i-chardev.png");
  gtk_widget_show (image4);
  gtk_box_pack_start (GTK_BOX (hbox6), image4, FALSE, TRUE, 0);

  label305 = gtk_label_new (_("Character Devices"));
  gtk_widget_show (label305);
  gtk_box_pack_start (GTK_BOX (hbox6), label305, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (label305), 10, 0);

  hbox7 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox7);
  gtk_table_attach (GTK_TABLE (table3), hbox7, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  image5 = create_pixmap (window1, "i-blockdev.png");
  gtk_widget_show (image5);
  gtk_box_pack_start (GTK_BOX (hbox7), image5, FALSE, TRUE, 0);

  label306 = gtk_label_new (_("Block Devices"));
  gtk_widget_show (label306);
  gtk_box_pack_start (GTK_BOX (hbox7), label306, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (label306), 10, 0);

  scrolledwindow7 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_show (scrolledwindow7);
  gtk_table_attach (GTK_TABLE (table3), scrolledwindow7, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 10, 10);

  gtv_block = gtk_tree_view_new ();
  gtk_widget_show (gtv_block);
  gtk_container_add (GTK_CONTAINER (scrolledwindow7), gtv_block);

  scrolledwindow6 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_show (scrolledwindow6);
  gtk_table_attach (GTK_TABLE (table3), scrolledwindow6, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 10, 10);

  gtv_char = gtk_tree_view_new ();
  gtk_widget_show (gtv_char);
  gtk_container_add (GTK_CONTAINER (scrolledwindow6), gtv_char);

  btn_dev_load = gtk_button_new ();
  gtk_widget_show (btn_dev_load);
  gtk_table_attach (GTK_TABLE (table3), btn_dev_load, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  alignment11 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment11);
  gtk_container_add (GTK_CONTAINER (btn_dev_load), alignment11);

  hbox12 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox12);
  gtk_container_add (GTK_CONTAINER (alignment11), hbox12);

  image10 = create_pixmap (window1, "reload.png");
  gtk_widget_show (image10);
  gtk_box_pack_start (GTK_BOX (hbox12), image10, FALSE, FALSE, 0);

  label340 = gtk_label_new_with_mnemonic (_("Reload"));
  gtk_widget_show (label340);
  gtk_box_pack_start (GTK_BOX (hbox12), label340, FALSE, FALSE, 0);

  hbox5 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox5);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (nb_main), gtk_notebook_get_nth_page (GTK_NOTEBOOK (nb_main), 2), hbox5);

  image3 = create_pixmap (window1, "i-chardev.png");
  gtk_widget_show (image3);
  gtk_box_pack_start (GTK_BOX (hbox5), image3, FALSE, FALSE, 0);

  label304 = gtk_label_new (_("Devices"));
  gtk_widget_show (label304);
  gtk_box_pack_start (GTK_BOX (hbox5), label304, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (label304), 2, 0);

  table4 = gtk_table_new (4, 2, FALSE);
  gtk_widget_show (table4);
  gtk_container_add (GTK_CONTAINER (nb_main), table4);

  fr_identification = gtk_frame_new (NULL);
  gtk_widget_show (fr_identification);
  gtk_table_attach (GTK_TABLE (table4), fr_identification, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 5, 5);
  gtk_frame_set_shadow_type (GTK_FRAME (fr_identification), GTK_SHADOW_IN);

  alignment2 = gtk_alignment_new (0.5, 0.5, 1, 1);
  gtk_widget_show (alignment2);
  gtk_container_add (GTK_CONTAINER (fr_identification), alignment2);
  gtk_alignment_set_padding (GTK_ALIGNMENT (alignment2), 0, 0, 12, 0);

  table5 = gtk_table_new (2, 2, FALSE);
  gtk_widget_show (table5);
  gtk_container_add (GTK_CONTAINER (alignment2), table5);

  ent_hostname = gtk_entry_new ();
  gtk_widget_show (ent_hostname);
  gtk_table_attach (GTK_TABLE (table5), ent_hostname, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);

  label309 = gtk_label_new (_("Host name"));
  gtk_widget_show (label309);
  gtk_table_attach (GTK_TABLE (table5), label309, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 0);
  gtk_misc_set_alignment (GTK_MISC (label309), 0, 0.5);

  label310 = gtk_label_new (_("Domain name"));
  gtk_widget_show (label310);
  gtk_table_attach (GTK_TABLE (table5), label310, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 0);
  gtk_misc_set_alignment (GTK_MISC (label310), 0, 0.5);

  ent_domainname = gtk_entry_new ();
  gtk_widget_show (ent_domainname);
  gtk_table_attach (GTK_TABLE (table5), ent_domainname, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);

  label308 = gtk_label_new (_("<b>Identification</b>"));
  gtk_widget_show (label308);
  gtk_frame_set_label_widget (GTK_FRAME (fr_identification), label308);
  gtk_label_set_use_markup (GTK_LABEL (label308), TRUE);

  frame3 = gtk_frame_new (NULL);
  gtk_widget_show (frame3);
  gtk_table_attach (GTK_TABLE (table4), frame3, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 5, 5);
  gtk_frame_set_shadow_type (GTK_FRAME (frame3), GTK_SHADOW_IN);

  alignment3 = gtk_alignment_new (0.5, 0.5, 1, 1);
  gtk_widget_show (alignment3);
  gtk_container_add (GTK_CONTAINER (frame3), alignment3);
  gtk_alignment_set_padding (GTK_ALIGNMENT (alignment3), 0, 0, 12, 0);

  table6 = gtk_table_new (5, 2, FALSE);
  gtk_widget_show (table6);
  gtk_container_add (GTK_CONTAINER (alignment3), table6);

  label312 = gtk_label_new (_("File descriptors max."));
  gtk_widget_show (label312);
  gtk_table_attach (GTK_TABLE (table6), label312, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (label312), 0, 0.5);

  label313 = gtk_label_new (_("Allocated file descriptors"));
  gtk_widget_show (label313);
  gtk_table_attach (GTK_TABLE (table6), label313, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (label313), 0, 0.5);

  label314 = gtk_label_new (_("Freed file descriptors"));
  gtk_widget_show (label314);
  gtk_table_attach (GTK_TABLE (table6), label314, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (label314), 0, 0.5);

  label316 = gtk_label_new (_("Allocated i-node"));
  gtk_widget_show (label316);
  gtk_table_attach (GTK_TABLE (table6), label316, 0, 1, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (label316), 0, 0.5);

  label315 = gtk_label_new (_("i-node max."));
  gtk_widget_show (label315);
  gtk_table_attach (GTK_TABLE (table6), label315, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (label315), 0, 0.5);

  spb_fdmax_adj = gtk_adjustment_new (0, -1, 1e+08, 1, 10, 10);
  spb_fdmax = gtk_spin_button_new (GTK_ADJUSTMENT (spb_fdmax_adj), 1, 0);
  gtk_widget_show (spb_fdmax);
  gtk_table_attach (GTK_TABLE (table6), spb_fdmax, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spb_fdmax), TRUE);

  lbl_fda = gtk_label_new ("");
  gtk_widget_show (lbl_fda);
  gtk_table_attach (GTK_TABLE (table6), lbl_fda, 1, 2, 1, 2,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (lbl_fda), 0, 0.5);

  lbl_ufd = gtk_label_new ("");
  gtk_widget_show (lbl_ufd);
  gtk_table_attach (GTK_TABLE (table6), lbl_ufd, 1, 2, 2, 3,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (lbl_ufd), 0, 0.5);

  lbl_ina = gtk_label_new ("");
  gtk_widget_show (lbl_ina);
  gtk_table_attach (GTK_TABLE (table6), lbl_ina, 1, 2, 4, 5,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (lbl_ina), 0, 0.5);

  lbl_inmax = gtk_label_new ("");
  gtk_widget_show (lbl_inmax);
  gtk_table_attach (GTK_TABLE (table6), lbl_inmax, 1, 2, 3, 4,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (lbl_inmax), 0, 0.5);

  label311 = gtk_label_new (_("<b>Files</b>"));
  gtk_widget_show (label311);
  gtk_frame_set_label_widget (GTK_FRAME (frame3), label311);
  gtk_label_set_use_markup (GTK_LABEL (label311), TRUE);

  frame4 = gtk_frame_new (NULL);
  gtk_widget_show (frame4);
  gtk_table_attach (GTK_TABLE (table4), frame4, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 5, 5);
  gtk_frame_set_shadow_type (GTK_FRAME (frame4), GTK_SHADOW_IN);

  alignment4 = gtk_alignment_new (0.5, 0.5, 1, 1);
  gtk_widget_show (alignment4);
  gtk_container_add (GTK_CONTAINER (frame4), alignment4);
  gtk_alignment_set_padding (GTK_ALIGNMENT (alignment4), 0, 0, 12, 0);

  table7 = gtk_table_new (3, 2, FALSE);
  gtk_widget_show (table7);
  gtk_container_add (GTK_CONTAINER (alignment4), table7);

  label321 = gtk_label_new (_("Max. pages"));
  gtk_widget_show (label321);
  gtk_table_attach (GTK_TABLE (table7), label321, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (label321), 0, 0.5);

  label322 = gtk_label_new (_("Max. Segments"));
  gtk_widget_show (label322);
  gtk_table_attach (GTK_TABLE (table7), label322, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (label322), 0, 0.5);

  label323 = gtk_label_new (_("Max. segment size"));
  gtk_widget_show (label323);
  gtk_table_attach (GTK_TABLE (table7), label323, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (label323), 0, 0.5);

  spb_max_pages_adj = gtk_adjustment_new (1, -1, 1e+08, 1, 10, 10);
  spb_max_pages = gtk_spin_button_new (GTK_ADJUSTMENT (spb_max_pages_adj), 1, 0);
  gtk_widget_show (spb_max_pages);
  gtk_table_attach (GTK_TABLE (table7), spb_max_pages, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 5, 0);

  spb_max_segs_adj = gtk_adjustment_new (1, -1, 1e+06, 1, 10, 10);
  spb_max_segs = gtk_spin_button_new (GTK_ADJUSTMENT (spb_max_segs_adj), 1, 0);
  gtk_widget_show (spb_max_segs);
  gtk_table_attach (GTK_TABLE (table7), spb_max_segs, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 5, 0);

  spb_seg_size_adj = gtk_adjustment_new (1, -1, 1e+08, 1, 10, 10);
  spb_seg_size = gtk_spin_button_new (GTK_ADJUSTMENT (spb_seg_size_adj), 1, 0);
  gtk_widget_show (spb_seg_size);
  gtk_table_attach (GTK_TABLE (table7), spb_seg_size, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 5, 0);

  label320 = gtk_label_new (_("<b>Shared memory</b>"));
  gtk_widget_show (label320);
  gtk_frame_set_label_widget (GTK_FRAME (frame4), label320);
  gtk_label_set_use_markup (GTK_LABEL (label320), TRUE);

  frame5 = gtk_frame_new (NULL);
  gtk_widget_show (frame5);
  gtk_table_attach (GTK_TABLE (table4), frame5, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 5, 5);
  gtk_frame_set_shadow_type (GTK_FRAME (frame5), GTK_SHADOW_IN);

  alignment5 = gtk_alignment_new (0.5, 0.5, 1, 1);
  gtk_widget_show (alignment5);
  gtk_container_add (GTK_CONTAINER (frame5), alignment5);
  gtk_alignment_set_padding (GTK_ALIGNMENT (alignment5), 0, 0, 12, 0);

  table8 = gtk_table_new (3, 2, FALSE);
  gtk_widget_show (table8);
  gtk_container_add (GTK_CONTAINER (alignment5), table8);

  label325 = gtk_label_new (_("Max. mesg. queues"));
  gtk_widget_show (label325);
  gtk_table_attach (GTK_TABLE (table8), label325, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (label325), 0, 0.5);

  label326 = gtk_label_new (_("Max. mesg. per queue"));
  gtk_widget_show (label326);
  gtk_table_attach (GTK_TABLE (table8), label326, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (label326), 0, 0.5);

  label335 = gtk_label_new (_("Max msg. size"));
  gtk_widget_show (label335);
  gtk_table_attach (GTK_TABLE (table8), label335, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (label335), 0, 0.5);

  spb_mq_adj = gtk_adjustment_new (1, -1, 1e+06, 1, 10, 10);
  spb_mq = gtk_spin_button_new (GTK_ADJUSTMENT (spb_mq_adj), 1, 0);
  gtk_widget_show (spb_mq);
  gtk_table_attach (GTK_TABLE (table8), spb_mq, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 5, 0);

  spb_max_mpq_adj = gtk_adjustment_new (1, -1, 1e+06, 1, 10, 10);
  spb_max_mpq = gtk_spin_button_new (GTK_ADJUSTMENT (spb_max_mpq_adj), 1, 0);
  gtk_widget_show (spb_max_mpq);
  gtk_table_attach (GTK_TABLE (table8), spb_max_mpq, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 5, 0);

  spb_max_ms_adj = gtk_adjustment_new (1, -1, 1e+06, 1, 10, 10);
  spb_max_ms = gtk_spin_button_new (GTK_ADJUSTMENT (spb_max_ms_adj), 1, 0);
  gtk_widget_show (spb_max_ms);
  gtk_table_attach (GTK_TABLE (table8), spb_max_ms, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 5, 0);

  label324 = gtk_label_new (_("<b>RT POSIX signals</b>"));
  gtk_widget_show (label324);
  gtk_frame_set_label_widget (GTK_FRAME (frame5), label324);
  gtk_label_set_use_markup (GTK_LABEL (label324), TRUE);

  frame6 = gtk_frame_new (NULL);
  gtk_widget_show (frame6);
  gtk_table_attach (GTK_TABLE (table4), frame6, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 5, 5);
  gtk_frame_set_shadow_type (GTK_FRAME (frame6), GTK_SHADOW_IN);

  alignment6 = gtk_alignment_new (0.5, 0.5, 1, 1);
  gtk_widget_show (alignment6);
  gtk_container_add (GTK_CONTAINER (frame6), alignment6);
  gtk_alignment_set_padding (GTK_ALIGNMENT (alignment6), 0, 0, 12, 0);

  table9 = gtk_table_new (4, 2, FALSE);
  gtk_widget_show (table9);
  gtk_container_add (GTK_CONTAINER (alignment6), table9);

  spb_sem_per_id_adj = gtk_adjustment_new (1, -1, 1e+06, 1, 10, 10);
  spb_sem_per_id = gtk_spin_button_new (GTK_ADJUSTMENT (spb_sem_per_id_adj), 1, 0);
  gtk_widget_show (spb_sem_per_id);
  gtk_table_attach (GTK_TABLE (table9), spb_sem_per_id, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  spb_sem_val_adj = gtk_adjustment_new (1, -1, 1e+06, 1, 10, 10);
  spb_sem_val = gtk_spin_button_new (GTK_ADJUSTMENT (spb_sem_val_adj), 1, 0);
  gtk_widget_show (spb_sem_val);
  gtk_table_attach (GTK_TABLE (table9), spb_sem_val, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  spb_ops_adj = gtk_adjustment_new (1, -1, 1e+06, 1, 10, 10);
  spb_ops = gtk_spin_button_new (GTK_ADJUSTMENT (spb_ops_adj), 1, 0);
  gtk_widget_show (spb_ops);
  gtk_table_attach (GTK_TABLE (table9), spb_ops, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  spb_sem_id_adj = gtk_adjustment_new (1, -1, 1e+06, 1, 10, 10);
  spb_sem_id = gtk_spin_button_new (GTK_ADJUSTMENT (spb_sem_id_adj), 1, 0);
  gtk_widget_show (spb_sem_id);
  gtk_table_attach (GTK_TABLE (table9), spb_sem_id, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label329 = gtk_label_new (_("Max. sem. in a set"));
  gtk_widget_show (label329);
  gtk_table_attach (GTK_TABLE (table9), label329, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (label329), 0, 0.5);

  label330 = gtk_label_new (_("Max. sem. in system"));
  gtk_widget_show (label330);
  gtk_table_attach (GTK_TABLE (table9), label330, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (label330), 0, 0.5);

  label331 = gtk_label_new (_("Max. ops. per call"));
  gtk_widget_show (label331);
  gtk_table_attach (GTK_TABLE (table9), label331, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (label331), 0, 0.5);

  label332 = gtk_label_new (_("Max. sem. sets"));
  gtk_widget_show (label332);
  gtk_table_attach (GTK_TABLE (table9), label332, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (label332), 0, 0.5);

  label328 = gtk_label_new (_("<b>Semaphores</b>"));
  gtk_widget_show (label328);
  gtk_frame_set_label_widget (GTK_FRAME (frame6), label328);
  gtk_label_set_use_markup (GTK_LABEL (label328), TRUE);

  frame7 = gtk_frame_new (NULL);
  gtk_widget_show (frame7);
  gtk_table_attach (GTK_TABLE (table4), frame7, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 5, 5);
  gtk_frame_set_shadow_type (GTK_FRAME (frame7), GTK_SHADOW_IN);

  alignment7 = gtk_alignment_new (0.5, 0.5, 1, 1);
  gtk_widget_show (alignment7);
  gtk_container_add (GTK_CONTAINER (frame7), alignment7);
  gtk_alignment_set_padding (GTK_ALIGNMENT (alignment7), 0, 0, 12, 0);

  table10 = gtk_table_new (1, 2, FALSE);
  gtk_widget_show (table10);
  gtk_container_add (GTK_CONTAINER (alignment7), table10);

  spb_maxthreads_adj = gtk_adjustment_new (0, -1, 1e+06, 1, 10, 10);
  spb_maxthreads = gtk_spin_button_new (GTK_ADJUSTMENT (spb_maxthreads_adj), 1, 0);
  gtk_widget_show (spb_maxthreads);
  gtk_table_attach (GTK_TABLE (table10), spb_maxthreads, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label334 = gtk_label_new (_("Max. threads"));
  gtk_widget_show (label334);
  gtk_table_attach (GTK_TABLE (table10), label334, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (label334), 0, 0.5);

  label333 = gtk_label_new (_("<b>Threads</b>"));
  gtk_widget_show (label333);
  gtk_frame_set_label_widget (GTK_FRAME (frame7), label333);
  gtk_label_set_use_markup (GTK_LABEL (label333), TRUE);

  btn_write = gtk_button_new ();
  gtk_widget_show (btn_write);
  gtk_table_attach (GTK_TABLE (table4), btn_write, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 5);

  alignment10 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment10);
  gtk_container_add (GTK_CONTAINER (btn_write), alignment10);

  hbox11 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox11);
  gtk_container_add (GTK_CONTAINER (alignment10), hbox11);

  image9 = create_pixmap (window1, "button_ok.png");
  gtk_widget_show (image9);
  gtk_box_pack_start (GTK_BOX (hbox11), image9, FALSE, FALSE, 0);

  label339 = gtk_label_new_with_mnemonic (_("Write settings"));
  gtk_widget_show (label339);
  gtk_box_pack_start (GTK_BOX (hbox11), label339, FALSE, FALSE, 0);

  btn_load = gtk_button_new ();
  gtk_widget_show (btn_load);
  gtk_table_attach (GTK_TABLE (table4), btn_load, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 5);

  alignment9 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_show (alignment9);
  gtk_container_add (GTK_CONTAINER (btn_load), alignment9);

  hbox10 = gtk_hbox_new (FALSE, 2);
  gtk_widget_show (hbox10);
  gtk_container_add (GTK_CONTAINER (alignment9), hbox10);

  image8 = create_pixmap (window1, "reload.png");
  gtk_widget_show (image8);
  gtk_box_pack_start (GTK_BOX (hbox10), image8, FALSE, FALSE, 0);

  label338 = gtk_label_new_with_mnemonic (_("Load current values"));
  gtk_widget_show (label338);
  gtk_box_pack_start (GTK_BOX (hbox10), label338, FALSE, FALSE, 0);

  hbox8 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox8);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (nb_main), gtk_notebook_get_nth_page (GTK_NOTEBOOK (nb_main), 3), hbox8);

  image6 = create_pixmap (window1, "gedit-plugin-manager.png");
  gtk_widget_show (image6);
  gtk_box_pack_start (GTK_BOX (hbox8), image6, FALSE, FALSE, 0);

  label307 = gtk_label_new (_("Settings"));
  gtk_widget_show (label307);
  gtk_box_pack_start (GTK_BOX (hbox8), label307, FALSE, FALSE, 0);

  table12 = gtk_table_new (1, 2, FALSE);
  gtk_widget_show (table12);
  gtk_container_add (GTK_CONTAINER (nb_main), table12);

  table15 = gtk_table_new (1, 1, FALSE);
  gtk_widget_show (table15);
  gtk_table_attach (GTK_TABLE (table12), table15, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  frame10 = gtk_frame_new (NULL);
  gtk_widget_show (frame10);
  gtk_table_attach (GTK_TABLE (table15), frame10, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 5, 15);
  gtk_frame_set_shadow_type (GTK_FRAME (frame10), GTK_SHADOW_IN);

  alignment13 = gtk_alignment_new (0.5, 0.5, 1, 1);
  gtk_widget_show (alignment13);
  gtk_container_add (GTK_CONTAINER (frame10), alignment13);
  gtk_alignment_set_padding (GTK_ALIGNMENT (alignment13), 0, 0, 12, 0);

  table16 = gtk_table_new (1, 2, FALSE);
  gtk_widget_show (table16);
  gtk_container_add (GTK_CONTAINER (alignment13), table16);

  table13 = gtk_table_new (8, 2, FALSE);
  gtk_widget_show (table13);
  gtk_table_attach (GTK_TABLE (table16), table13, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);

  label345 = gtk_label_new (_("User"));
  gtk_widget_show (label345);
  gtk_table_attach (GTK_TABLE (table13), label345, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label345), 0, 0.5);

  label346 = gtk_label_new (_("Nice"));
  gtk_widget_show (label346);
  gtk_table_attach (GTK_TABLE (table13), label346, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label346), 0, 0.5);

  label347 = gtk_label_new (_("System"));
  gtk_widget_show (label347);
  gtk_table_attach (GTK_TABLE (table13), label347, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label347), 0, 0.5);

  label348 = gtk_label_new (_("Idle"));
  gtk_widget_show (label348);
  gtk_table_attach (GTK_TABLE (table13), label348, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label348), 0, 0.5);

  label349 = gtk_label_new (_("I/O Wait"));
  gtk_widget_show (label349);
  gtk_table_attach (GTK_TABLE (table13), label349, 0, 1, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label349), 0, 0.5);

  label350 = gtk_label_new (_("IRQ"));
  gtk_widget_show (label350);
  gtk_table_attach (GTK_TABLE (table13), label350, 0, 1, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label350), 0, 0.5);

  label351 = gtk_label_new (_("Softirq"));
  gtk_widget_show (label351);
  gtk_table_attach (GTK_TABLE (table13), label351, 0, 1, 6, 7,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label351), 0, 0.5);

  label352 = gtk_label_new (_("Context switches"));
  gtk_widget_show (label352);
  gtk_table_attach (GTK_TABLE (table13), label352, 0, 1, 7, 8,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label352), 0, 0.5);

  lbl_context = gtk_label_new ("");
  gtk_widget_show (lbl_context);
  gtk_table_attach (GTK_TABLE (table13), lbl_context, 1, 2, 7, 8,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (lbl_context), 0, 0.5);

  lbl_softirq = gtk_label_new ("");
  gtk_widget_show (lbl_softirq);
  gtk_table_attach (GTK_TABLE (table13), lbl_softirq, 1, 2, 6, 7,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (lbl_softirq), 0, 0.5);

  lbl_irq = gtk_label_new ("");
  gtk_widget_show (lbl_irq);
  gtk_table_attach (GTK_TABLE (table13), lbl_irq, 1, 2, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (lbl_irq), 0, 0.5);

  lbl_iowait = gtk_label_new ("");
  gtk_widget_show (lbl_iowait);
  gtk_table_attach (GTK_TABLE (table13), lbl_iowait, 1, 2, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (lbl_iowait), 0, 0.5);

  lbl_idle = gtk_label_new ("");
  gtk_widget_show (lbl_idle);
  gtk_table_attach (GTK_TABLE (table13), lbl_idle, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (lbl_idle), 0, 0.5);

  lbl_system = gtk_label_new ("");
  gtk_widget_show (lbl_system);
  gtk_table_attach (GTK_TABLE (table13), lbl_system, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (lbl_system), 0, 0.5);

  lbl_nice = gtk_label_new ("");
  gtk_widget_show (lbl_nice);
  gtk_table_attach (GTK_TABLE (table13), lbl_nice, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (lbl_nice), 0, 0.5);

  lbl_user = gtk_label_new ("");
  gtk_widget_show (lbl_user);
  gtk_table_attach (GTK_TABLE (table13), lbl_user, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (lbl_user), 0, 0.5);

  table17 = gtk_table_new (2, 1, FALSE);
  gtk_widget_show (table17);
  gtk_table_attach (GTK_TABLE (table16), table17, 1, 2, 0, 1,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 5, 50);

  label363 = gtk_label_new (_("CPU Use"));
  gtk_widget_show (label363);
  gtk_table_attach (GTK_TABLE (table17), label363, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label363), 0, 0.5);

  pb_cpu = gtk_progress_bar_new ();
  gtk_widget_show (pb_cpu);
  gtk_table_attach (GTK_TABLE (table17), pb_cpu, 0, 1, 0, 1,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_progress_bar_set_orientation (GTK_PROGRESS_BAR (pb_cpu), GTK_PROGRESS_BOTTOM_TO_TOP);
  gtk_progress_bar_set_pulse_step (GTK_PROGRESS_BAR (pb_cpu), 0.01);

  label344 = gtk_label_new (_("<b>System Time (ms)</b>"));
  gtk_widget_show (label344);
  gtk_frame_set_label_widget (GTK_FRAME (frame10), label344);
  gtk_label_set_use_markup (GTK_LABEL (label344), TRUE);

  frame9 = gtk_frame_new (NULL);
  gtk_widget_show (frame9);
  gtk_table_attach (GTK_TABLE (table12), frame9, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 5, 15);
  gtk_frame_set_shadow_type (GTK_FRAME (frame9), GTK_SHADOW_IN);

  alignment12 = gtk_alignment_new (0.5, 0.5, 1, 1);
  gtk_widget_show (alignment12);
  gtk_container_add (GTK_CONTAINER (frame9), alignment12);
  gtk_alignment_set_padding (GTK_ALIGNMENT (alignment12), 0, 0, 12, 0);

  table14 = gtk_table_new (5, 2, FALSE);
  gtk_widget_show (table14);
  gtk_container_add (GTK_CONTAINER (alignment12), table14);

  label361 = gtk_label_new (_("Temperature"));
  gtk_widget_show (label361);
  gtk_table_attach (GTK_TABLE (table14), label361, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (label361), 0, 0.5);

  label362 = gtk_label_new (_("Battery"));
  gtk_widget_show (label362);
  gtk_table_attach (GTK_TABLE (table14), label362, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (label362), 0, 0.5);

  pb_temp = gtk_progress_bar_new ();
  gtk_widget_show (pb_temp);
  gtk_table_attach (GTK_TABLE (table14), pb_temp, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_progress_bar_set_pulse_step (GTK_PROGRESS_BAR (pb_temp), 0.01);

  pb_batt = gtk_progress_bar_new ();
  gtk_widget_show (pb_batt);
  gtk_table_attach (GTK_TABLE (table14), pb_batt, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_progress_bar_set_pulse_step (GTK_PROGRESS_BAR (pb_batt), 0.01);

  label364 = gtk_label_new (_("mAh"));
  gtk_widget_show (label364);
  gtk_table_attach (GTK_TABLE (table14), label364, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label364), 0, 0.5);

  label365 = gtk_label_new (_("C"));
  gtk_widget_show (label365);
  gtk_table_attach (GTK_TABLE (table14), label365, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label365), 0, 0.5);

  frame11 = gtk_frame_new (NULL);
  gtk_widget_show (frame11);
  gtk_table_attach (GTK_TABLE (table14), frame11, 0, 1, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 5, 5);
  gtk_frame_set_shadow_type (GTK_FRAME (frame11), GTK_SHADOW_NONE);

  alignment14 = gtk_alignment_new (0.5, 0.5, 1, 1);
  gtk_widget_show (alignment14);
  gtk_container_add (GTK_CONTAINER (frame11), alignment14);
  gtk_alignment_set_padding (GTK_ALIGNMENT (alignment14), 0, 0, 12, 0);

  table18 = gtk_table_new (5, 2, FALSE);
  gtk_widget_show (table18);
  gtk_container_add (GTK_CONTAINER (alignment14), table18);

  label367 = gtk_label_new (_("Capacity"));
  gtk_widget_show (label367);
  gtk_table_attach (GTK_TABLE (table18), label367, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (label367), 0, 0.5);

  label368 = gtk_label_new (_("Last full capacity"));
  gtk_widget_show (label368);
  gtk_table_attach (GTK_TABLE (table18), label368, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (label368), 0, 0.5);

  label369 = gtk_label_new (_("Capacity warning"));
  gtk_widget_show (label369);
  gtk_table_attach (GTK_TABLE (table18), label369, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (label369), 0, 0.5);

  label370 = gtk_label_new (_("Capacity low"));
  gtk_widget_show (label370);
  gtk_table_attach (GTK_TABLE (table18), label370, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (label370), 0, 0.5);

  label371 = gtk_label_new (_("Battery type"));
  gtk_widget_show (label371);
  gtk_table_attach (GTK_TABLE (table18), label371, 0, 1, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 5);
  gtk_misc_set_alignment (GTK_MISC (label371), 0, 0.5);

  lbl_cap = gtk_label_new ("");
  gtk_widget_show (lbl_cap);
  gtk_table_attach (GTK_TABLE (table18), lbl_cap, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (lbl_cap), 0, 0.5);

  lbl_last_cap = gtk_label_new ("");
  gtk_widget_show (lbl_last_cap);
  gtk_table_attach (GTK_TABLE (table18), lbl_last_cap, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (lbl_last_cap), 0, 0.5);

  lbl_cap_warning = gtk_label_new ("");
  gtk_widget_show (lbl_cap_warning);
  gtk_table_attach (GTK_TABLE (table18), lbl_cap_warning, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (lbl_cap_warning), 0, 0.5);

  lbl_cap_low = gtk_label_new ("");
  gtk_widget_show (lbl_cap_low);
  gtk_table_attach (GTK_TABLE (table18), lbl_cap_low, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (lbl_cap_low), 0, 0.5);

  lbl_batt_type = gtk_label_new ("");
  gtk_widget_show (lbl_batt_type);
  gtk_table_attach (GTK_TABLE (table18), lbl_batt_type, 1, 2, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (lbl_batt_type), 0, 0.5);

  hbox13 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox13);
  gtk_frame_set_label_widget (GTK_FRAME (frame11), hbox13);

  image11 = create_pixmap (window1, "gnome-dev-battery.png");
  gtk_widget_show (image11);
  gtk_box_pack_start (GTK_BOX (hbox13), image11, TRUE, TRUE, 0);

  label366 = gtk_label_new (_("Battery Info (mAh)"));
  gtk_widget_show (label366);
  gtk_box_pack_start (GTK_BOX (hbox13), label366, FALSE, FALSE, 0);

  label341 = gtk_label_new (_("<b>ACPI Info</b>"));
  gtk_widget_show (label341);
  gtk_frame_set_label_widget (GTK_FRAME (frame9), label341);
  gtk_label_set_use_markup (GTK_LABEL (label341), TRUE);

  hbox9 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox9);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (nb_main), gtk_notebook_get_nth_page (GTK_NOTEBOOK (nb_main), 4), hbox9);

  image7 = create_pixmap (window1, "gnome-computer.png");
  gtk_widget_show (image7);
  gtk_box_pack_start (GTK_BOX (hbox9), image7, FALSE, FALSE, 0);

  label337 = gtk_label_new (_("Misc"));
  gtk_widget_show (label337);
  gtk_box_pack_start (GTK_BOX (hbox9), label337, FALSE, FALSE, 0);

  g_signal_connect ((gpointer) window1, "delete_event",
                    G_CALLBACK (on_window1_delete_event),
                    NULL);
  g_signal_connect ((gpointer) btn_dev_load, "clicked",
                    G_CALLBACK (on_btn_dev_load_clicked),
                    NULL);
  g_signal_connect ((gpointer) btn_write, "clicked",
                    G_CALLBACK (on_btn_write_clicked),
                    NULL);
  g_signal_connect ((gpointer) btn_load, "clicked",
                    G_CALLBACK (on_btn_load_clicked),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (window1, window1, "window1");
  GLADE_HOOKUP_OBJECT (window1, vbox1, "vbox1");
  GLADE_HOOKUP_OBJECT (window1, menubar1, "menubar1");
  GLADE_HOOKUP_OBJECT (window1, menubar1_uiinfo[0].widget, "menuitem3");
  GLADE_HOOKUP_OBJECT (window1, menu3_uiinfo[0].widget, "imagemenuitem3");
  GLADE_HOOKUP_OBJECT (window1, menubar1_uiinfo[1].widget, "menuitem4");
  GLADE_HOOKUP_OBJECT (window1, menu4_uiinfo[0].widget, "imagemenuitem4");
  GLADE_HOOKUP_OBJECT (window1, nb_main, "nb_main");
  GLADE_HOOKUP_OBJECT (window1, hbox2, "hbox2");
  GLADE_HOOKUP_OBJECT (window1, table1, "table1");
  GLADE_HOOKUP_OBJECT (window1, label226, "label226");
  GLADE_HOOKUP_OBJECT (window1, label227, "label227");
  GLADE_HOOKUP_OBJECT (window1, label228, "label228");
  GLADE_HOOKUP_OBJECT (window1, label229, "label229");
  GLADE_HOOKUP_OBJECT (window1, label230, "label230");
  GLADE_HOOKUP_OBJECT (window1, label231, "label231");
  GLADE_HOOKUP_OBJECT (window1, label232, "label232");
  GLADE_HOOKUP_OBJECT (window1, label233, "label233");
  GLADE_HOOKUP_OBJECT (window1, label234, "label234");
  GLADE_HOOKUP_OBJECT (window1, label235, "label235");
  GLADE_HOOKUP_OBJECT (window1, label236, "label236");
  GLADE_HOOKUP_OBJECT (window1, label237, "label237");
  GLADE_HOOKUP_OBJECT (window1, label238, "label238");
  GLADE_HOOKUP_OBJECT (window1, label239, "label239");
  GLADE_HOOKUP_OBJECT (window1, lbl_processor, "lbl_processor");
  GLADE_HOOKUP_OBJECT (window1, lbl_vendor, "lbl_vendor");
  GLADE_HOOKUP_OBJECT (window1, lbl_family, "lbl_family");
  GLADE_HOOKUP_OBJECT (window1, lbl_model, "lbl_model");
  GLADE_HOOKUP_OBJECT (window1, lbl_model_name, "lbl_model_name");
  GLADE_HOOKUP_OBJECT (window1, lbl_stepping, "lbl_stepping");
  GLADE_HOOKUP_OBJECT (window1, lbl_Mhz, "lbl_Mhz");
  GLADE_HOOKUP_OBJECT (window1, lbl_cache, "lbl_cache");
  GLADE_HOOKUP_OBJECT (window1, lbl_fpu, "lbl_fpu");
  GLADE_HOOKUP_OBJECT (window1, lbl_fpu_exception, "lbl_fpu_exception");
  GLADE_HOOKUP_OBJECT (window1, lbl_cpu_id_level, "lbl_cpu_id_level");
  GLADE_HOOKUP_OBJECT (window1, lbl_wp, "lbl_wp");
  GLADE_HOOKUP_OBJECT (window1, lbl_bogomips, "lbl_bogomips");
  GLADE_HOOKUP_OBJECT (window1, scrolledwindow5, "scrolledwindow5");
  GLADE_HOOKUP_OBJECT (window1, viewport1, "viewport1");
  GLADE_HOOKUP_OBJECT (window1, lbl_flags, "lbl_flags");
  GLADE_HOOKUP_OBJECT (window1, hbox3, "hbox3");
  GLADE_HOOKUP_OBJECT (window1, image1, "image1");
  GLADE_HOOKUP_OBJECT (window1, label302, "label302");
  GLADE_HOOKUP_OBJECT (window1, hbox1, "hbox1");
  GLADE_HOOKUP_OBJECT (window1, table2, "table2");
  GLADE_HOOKUP_OBJECT (window1, lbl_total, "lbl_total");
  GLADE_HOOKUP_OBJECT (window1, lbl_free, "lbl_free");
  GLADE_HOOKUP_OBJECT (window1, lbl_buffers, "lbl_buffers");
  GLADE_HOOKUP_OBJECT (window1, lbl_cached, "lbl_cached");
  GLADE_HOOKUP_OBJECT (window1, lbl_swap_cached, "lbl_swap_cached");
  GLADE_HOOKUP_OBJECT (window1, lbl_active, "lbl_active");
  GLADE_HOOKUP_OBJECT (window1, lbl_inactive, "lbl_inactive");
  GLADE_HOOKUP_OBJECT (window1, lbl_dirty, "lbl_dirty");
  GLADE_HOOKUP_OBJECT (window1, lbl_hp_total, "lbl_hp_total");
  GLADE_HOOKUP_OBJECT (window1, lbl_hp_free, "lbl_hp_free");
  GLADE_HOOKUP_OBJECT (window1, lbl_hp_size, "lbl_hp_size");
  GLADE_HOOKUP_OBJECT (window1, lbl_high_total, "lbl_high_total");
  GLADE_HOOKUP_OBJECT (window1, lbl_high_free, "lbl_high_free");
  GLADE_HOOKUP_OBJECT (window1, lbl_low_total, "lbl_low_total");
  GLADE_HOOKUP_OBJECT (window1, lbl_low_free, "lbl_low_free");
  GLADE_HOOKUP_OBJECT (window1, lbl_swap_total, "lbl_swap_total");
  GLADE_HOOKUP_OBJECT (window1, lbl_swap_free, "lbl_swap_free");
  GLADE_HOOKUP_OBJECT (window1, label245, "label245");
  GLADE_HOOKUP_OBJECT (window1, label246, "label246");
  GLADE_HOOKUP_OBJECT (window1, label248, "label248");
  GLADE_HOOKUP_OBJECT (window1, label247, "label247");
  GLADE_HOOKUP_OBJECT (window1, label249, "label249");
  GLADE_HOOKUP_OBJECT (window1, label250, "label250");
  GLADE_HOOKUP_OBJECT (window1, label251, "label251");
  GLADE_HOOKUP_OBJECT (window1, label252, "label252");
  GLADE_HOOKUP_OBJECT (window1, label253, "label253");
  GLADE_HOOKUP_OBJECT (window1, label254, "label254");
  GLADE_HOOKUP_OBJECT (window1, label255, "label255");
  GLADE_HOOKUP_OBJECT (window1, label256, "label256");
  GLADE_HOOKUP_OBJECT (window1, label257, "label257");
  GLADE_HOOKUP_OBJECT (window1, label244, "label244");
  GLADE_HOOKUP_OBJECT (window1, label258, "label258");
  GLADE_HOOKUP_OBJECT (window1, label259, "label259");
  GLADE_HOOKUP_OBJECT (window1, label260, "label260");
  GLADE_HOOKUP_OBJECT (window1, vbox3, "vbox3");
  GLADE_HOOKUP_OBJECT (window1, frame8, "frame8");
  GLADE_HOOKUP_OBJECT (window1, alignment8, "alignment8");
  GLADE_HOOKUP_OBJECT (window1, table11, "table11");
  GLADE_HOOKUP_OBJECT (window1, pb_swap, "pb_swap");
  GLADE_HOOKUP_OBJECT (window1, pb_mem, "pb_mem");
  GLADE_HOOKUP_OBJECT (window1, label336, "label336");
  GLADE_HOOKUP_OBJECT (window1, hbox4, "hbox4");
  GLADE_HOOKUP_OBJECT (window1, image2, "image2");
  GLADE_HOOKUP_OBJECT (window1, label303, "label303");
  GLADE_HOOKUP_OBJECT (window1, table3, "table3");
  GLADE_HOOKUP_OBJECT (window1, hbox6, "hbox6");
  GLADE_HOOKUP_OBJECT (window1, image4, "image4");
  GLADE_HOOKUP_OBJECT (window1, label305, "label305");
  GLADE_HOOKUP_OBJECT (window1, hbox7, "hbox7");
  GLADE_HOOKUP_OBJECT (window1, image5, "image5");
  GLADE_HOOKUP_OBJECT (window1, label306, "label306");
  GLADE_HOOKUP_OBJECT (window1, scrolledwindow7, "scrolledwindow7");
  GLADE_HOOKUP_OBJECT (window1, gtv_block, "gtv_block");
  GLADE_HOOKUP_OBJECT (window1, scrolledwindow6, "scrolledwindow6");
  GLADE_HOOKUP_OBJECT (window1, gtv_char, "gtv_char");
  GLADE_HOOKUP_OBJECT (window1, btn_dev_load, "btn_dev_load");
  GLADE_HOOKUP_OBJECT (window1, alignment11, "alignment11");
  GLADE_HOOKUP_OBJECT (window1, hbox12, "hbox12");
  GLADE_HOOKUP_OBJECT (window1, image10, "image10");
  GLADE_HOOKUP_OBJECT (window1, label340, "label340");
  GLADE_HOOKUP_OBJECT (window1, hbox5, "hbox5");
  GLADE_HOOKUP_OBJECT (window1, image3, "image3");
  GLADE_HOOKUP_OBJECT (window1, label304, "label304");
  GLADE_HOOKUP_OBJECT (window1, table4, "table4");
  GLADE_HOOKUP_OBJECT (window1, fr_identification, "fr_identification");
  GLADE_HOOKUP_OBJECT (window1, alignment2, "alignment2");
  GLADE_HOOKUP_OBJECT (window1, table5, "table5");
  GLADE_HOOKUP_OBJECT (window1, ent_hostname, "ent_hostname");
  GLADE_HOOKUP_OBJECT (window1, label309, "label309");
  GLADE_HOOKUP_OBJECT (window1, label310, "label310");
  GLADE_HOOKUP_OBJECT (window1, ent_domainname, "ent_domainname");
  GLADE_HOOKUP_OBJECT (window1, label308, "label308");
  GLADE_HOOKUP_OBJECT (window1, frame3, "frame3");
  GLADE_HOOKUP_OBJECT (window1, alignment3, "alignment3");
  GLADE_HOOKUP_OBJECT (window1, table6, "table6");
  GLADE_HOOKUP_OBJECT (window1, label312, "label312");
  GLADE_HOOKUP_OBJECT (window1, label313, "label313");
  GLADE_HOOKUP_OBJECT (window1, label314, "label314");
  GLADE_HOOKUP_OBJECT (window1, label316, "label316");
  GLADE_HOOKUP_OBJECT (window1, label315, "label315");
  GLADE_HOOKUP_OBJECT (window1, spb_fdmax, "spb_fdmax");
  GLADE_HOOKUP_OBJECT (window1, lbl_fda, "lbl_fda");
  GLADE_HOOKUP_OBJECT (window1, lbl_ufd, "lbl_ufd");
  GLADE_HOOKUP_OBJECT (window1, lbl_ina, "lbl_ina");
  GLADE_HOOKUP_OBJECT (window1, lbl_inmax, "lbl_inmax");
  GLADE_HOOKUP_OBJECT (window1, label311, "label311");
  GLADE_HOOKUP_OBJECT (window1, frame4, "frame4");
  GLADE_HOOKUP_OBJECT (window1, alignment4, "alignment4");
  GLADE_HOOKUP_OBJECT (window1, table7, "table7");
  GLADE_HOOKUP_OBJECT (window1, label321, "label321");
  GLADE_HOOKUP_OBJECT (window1, label322, "label322");
  GLADE_HOOKUP_OBJECT (window1, label323, "label323");
  GLADE_HOOKUP_OBJECT (window1, spb_max_pages, "spb_max_pages");
  GLADE_HOOKUP_OBJECT (window1, spb_max_segs, "spb_max_segs");
  GLADE_HOOKUP_OBJECT (window1, spb_seg_size, "spb_seg_size");
  GLADE_HOOKUP_OBJECT (window1, label320, "label320");
  GLADE_HOOKUP_OBJECT (window1, frame5, "frame5");
  GLADE_HOOKUP_OBJECT (window1, alignment5, "alignment5");
  GLADE_HOOKUP_OBJECT (window1, table8, "table8");
  GLADE_HOOKUP_OBJECT (window1, label325, "label325");
  GLADE_HOOKUP_OBJECT (window1, label326, "label326");
  GLADE_HOOKUP_OBJECT (window1, label335, "label335");
  GLADE_HOOKUP_OBJECT (window1, spb_mq, "spb_mq");
  GLADE_HOOKUP_OBJECT (window1, spb_max_mpq, "spb_max_mpq");
  GLADE_HOOKUP_OBJECT (window1, spb_max_ms, "spb_max_ms");
  GLADE_HOOKUP_OBJECT (window1, label324, "label324");
  GLADE_HOOKUP_OBJECT (window1, frame6, "frame6");
  GLADE_HOOKUP_OBJECT (window1, alignment6, "alignment6");
  GLADE_HOOKUP_OBJECT (window1, table9, "table9");
  GLADE_HOOKUP_OBJECT (window1, spb_sem_per_id, "spb_sem_per_id");
  GLADE_HOOKUP_OBJECT (window1, spb_sem_val, "spb_sem_val");
  GLADE_HOOKUP_OBJECT (window1, spb_ops, "spb_ops");
  GLADE_HOOKUP_OBJECT (window1, spb_sem_id, "spb_sem_id");
  GLADE_HOOKUP_OBJECT (window1, label329, "label329");
  GLADE_HOOKUP_OBJECT (window1, label330, "label330");
  GLADE_HOOKUP_OBJECT (window1, label331, "label331");
  GLADE_HOOKUP_OBJECT (window1, label332, "label332");
  GLADE_HOOKUP_OBJECT (window1, label328, "label328");
  GLADE_HOOKUP_OBJECT (window1, frame7, "frame7");
  GLADE_HOOKUP_OBJECT (window1, alignment7, "alignment7");
  GLADE_HOOKUP_OBJECT (window1, table10, "table10");
  GLADE_HOOKUP_OBJECT (window1, spb_maxthreads, "spb_maxthreads");
  GLADE_HOOKUP_OBJECT (window1, label334, "label334");
  GLADE_HOOKUP_OBJECT (window1, label333, "label333");
  GLADE_HOOKUP_OBJECT (window1, btn_write, "btn_write");
  GLADE_HOOKUP_OBJECT (window1, alignment10, "alignment10");
  GLADE_HOOKUP_OBJECT (window1, hbox11, "hbox11");
  GLADE_HOOKUP_OBJECT (window1, image9, "image9");
  GLADE_HOOKUP_OBJECT (window1, label339, "label339");
  GLADE_HOOKUP_OBJECT (window1, btn_load, "btn_load");
  GLADE_HOOKUP_OBJECT (window1, alignment9, "alignment9");
  GLADE_HOOKUP_OBJECT (window1, hbox10, "hbox10");
  GLADE_HOOKUP_OBJECT (window1, image8, "image8");
  GLADE_HOOKUP_OBJECT (window1, label338, "label338");
  GLADE_HOOKUP_OBJECT (window1, hbox8, "hbox8");
  GLADE_HOOKUP_OBJECT (window1, image6, "image6");
  GLADE_HOOKUP_OBJECT (window1, label307, "label307");
  GLADE_HOOKUP_OBJECT (window1, table12, "table12");
  GLADE_HOOKUP_OBJECT (window1, table15, "table15");
  GLADE_HOOKUP_OBJECT (window1, frame10, "frame10");
  GLADE_HOOKUP_OBJECT (window1, alignment13, "alignment13");
  GLADE_HOOKUP_OBJECT (window1, table16, "table16");
  GLADE_HOOKUP_OBJECT (window1, table13, "table13");
  GLADE_HOOKUP_OBJECT (window1, label345, "label345");
  GLADE_HOOKUP_OBJECT (window1, label346, "label346");
  GLADE_HOOKUP_OBJECT (window1, label347, "label347");
  GLADE_HOOKUP_OBJECT (window1, label348, "label348");
  GLADE_HOOKUP_OBJECT (window1, label349, "label349");
  GLADE_HOOKUP_OBJECT (window1, label350, "label350");
  GLADE_HOOKUP_OBJECT (window1, label351, "label351");
  GLADE_HOOKUP_OBJECT (window1, label352, "label352");
  GLADE_HOOKUP_OBJECT (window1, lbl_context, "lbl_context");
  GLADE_HOOKUP_OBJECT (window1, lbl_softirq, "lbl_softirq");
  GLADE_HOOKUP_OBJECT (window1, lbl_irq, "lbl_irq");
  GLADE_HOOKUP_OBJECT (window1, lbl_iowait, "lbl_iowait");
  GLADE_HOOKUP_OBJECT (window1, lbl_idle, "lbl_idle");
  GLADE_HOOKUP_OBJECT (window1, lbl_system, "lbl_system");
  GLADE_HOOKUP_OBJECT (window1, lbl_nice, "lbl_nice");
  GLADE_HOOKUP_OBJECT (window1, lbl_user, "lbl_user");
  GLADE_HOOKUP_OBJECT (window1, table17, "table17");
  GLADE_HOOKUP_OBJECT (window1, label363, "label363");
  GLADE_HOOKUP_OBJECT (window1, pb_cpu, "pb_cpu");
  GLADE_HOOKUP_OBJECT (window1, label344, "label344");
  GLADE_HOOKUP_OBJECT (window1, frame9, "frame9");
  GLADE_HOOKUP_OBJECT (window1, alignment12, "alignment12");
  GLADE_HOOKUP_OBJECT (window1, table14, "table14");
  GLADE_HOOKUP_OBJECT (window1, label361, "label361");
  GLADE_HOOKUP_OBJECT (window1, label362, "label362");
  GLADE_HOOKUP_OBJECT (window1, pb_temp, "pb_temp");
  GLADE_HOOKUP_OBJECT (window1, pb_batt, "pb_batt");
  GLADE_HOOKUP_OBJECT (window1, label364, "label364");
  GLADE_HOOKUP_OBJECT (window1, label365, "label365");
  GLADE_HOOKUP_OBJECT (window1, frame11, "frame11");
  GLADE_HOOKUP_OBJECT (window1, alignment14, "alignment14");
  GLADE_HOOKUP_OBJECT (window1, table18, "table18");
  GLADE_HOOKUP_OBJECT (window1, label367, "label367");
  GLADE_HOOKUP_OBJECT (window1, label368, "label368");
  GLADE_HOOKUP_OBJECT (window1, label369, "label369");
  GLADE_HOOKUP_OBJECT (window1, label370, "label370");
  GLADE_HOOKUP_OBJECT (window1, label371, "label371");
  GLADE_HOOKUP_OBJECT (window1, lbl_cap, "lbl_cap");
  GLADE_HOOKUP_OBJECT (window1, lbl_last_cap, "lbl_last_cap");
  GLADE_HOOKUP_OBJECT (window1, lbl_cap_warning, "lbl_cap_warning");
  GLADE_HOOKUP_OBJECT (window1, lbl_cap_low, "lbl_cap_low");
  GLADE_HOOKUP_OBJECT (window1, lbl_batt_type, "lbl_batt_type");
  GLADE_HOOKUP_OBJECT (window1, hbox13, "hbox13");
  GLADE_HOOKUP_OBJECT (window1, image11, "image11");
  GLADE_HOOKUP_OBJECT (window1, label366, "label366");
  GLADE_HOOKUP_OBJECT (window1, label341, "label341");
  GLADE_HOOKUP_OBJECT (window1, hbox9, "hbox9");
  GLADE_HOOKUP_OBJECT (window1, image7, "image7");
  GLADE_HOOKUP_OBJECT (window1, label337, "label337");

  return window1;
}

GtkWidget*
create_about (void)
{
  const gchar *authors[] = {
    "Founder and lead developer:",
    "Fernando Apestegu\303\255a <fernape@users.sourceforge.net>",
    "\nDevelopers:",
    "Jos\303\251 Manuel Barrios",
    "<jmbargar@users.sourceforge.net>",
    "Jokin Segundo",
    "<daedalvs@users.sourceforge.net>",
    "\nWebsite:",
    "M. Luz Lopez <mlopmar@users.sourceforge.net> ",
    "Julio Tejedor <jtejpal@users.sourceforge.net>",
    NULL
  };
  const gchar *documenters[] = {
    "Fernando Apestegu\303\255a <fernape@users.sourceforge.net>",
    "Jokin Segundo <daedalvs@users.sourceforge.net>",
    "M. Luz Lopez <mlopmar@users.sourceforge.net> ",
    "Julio Tejedor <jtejpal@users.sourceforge.net>",
    NULL
  };
  gchar *translators = "Philipp Weissenbacher (de)\nFernando Apesteguia (es)\nJokin Segundo (eu)\nTamara Forza (hr)\nTamara Forza (it)\nDaisuke Suzuki (ja)\nNick Khazov (ru)\nAbid Siddique (ur)\nJuin Chen (zh)";
  GdkPixbuf *about_logo_pixbuf;
  GtkWidget *about;
  GdkPixbuf *about_icon_pixbuf;

  about_logo_pixbuf = create_pixbuf ("spider-shadow48.png");
  about = gnome_about_new ("lkmonitor", VERSION,
                        _("Copyright (c) Fernando Apesteguia"),
                        _("Linux Kernel Monitor"),
                        authors,
                        documenters,
                        translators,
                        about_logo_pixbuf);
  gtk_container_set_border_width (GTK_CONTAINER (about), 5);
  about_icon_pixbuf = create_pixbuf ("spider-shadow16.png");
  if (about_icon_pixbuf)
    {
      gtk_window_set_icon (GTK_WINDOW (about), about_icon_pixbuf);
      gdk_pixbuf_unref (about_icon_pixbuf);
    }
  gtk_window_set_type_hint (GTK_WINDOW (about), GDK_WINDOW_TYPE_HINT_DIALOG);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (about, about, "about");

  return about;
}
